@@ -47,6 +47,7 @@ from gajim.common.modules.contacts import BareContact
 from gajim.common.modules.message import build_message_stanza
 from gajim.common.structs import OutgoingMessage
 from gajim.common.util.http import create_http_session
+from gajim.common.util.standards import get_rfc5646_lang
 from gajim.common.util.status import get_idle_status_message
 from gajim.common.util.text import to_one_line
 
@@ -78,7 +79,6 @@ class Client(Observable, ClientModules):
         address = app.settings.get_account_setting(self._account, 'address')
         self._address = JID.from_string(address)
 
-        self._priority = 0
         self._connect_machine_calls = 0
         self.addressing_supported = False
 
@@ -133,10 +133,6 @@ class Client(Observable, ClientModules):
             return self._idle_status_message
         return self._status_message
 
-    @property
-    def priority(self) -> int:
-        return self._priority
-
     @property
     def certificate(self):
         return self._client.peer_certificate[0]
@@ -170,6 +166,7 @@ class Client(Observable, ClientModules):
 
         self._client = NBXMPPClient(log_context=self._account)
         self.connection = self._client
+        self._client.set_lang(get_rfc5646_lang())
         self._client.set_domain(self._address.domain)
         self._client.set_username(self._address.localpart)
         self._client.set_resource(get_resource(self._account))
@@ -370,7 +367,7 @@ class Client(Observable, ClientModules):
 
     def get_own_contact(self) -> BareContact:
         jid = self.get_own_jid()
-        contact = self.get_module("Contacts").get_contact(jid)
+        contact = self.get_module("Contacts").get_contact(jid.bare)
         assert isinstance(contact, BareContact)
         return contact
 
@@ -457,9 +454,7 @@ class Client(Observable, ClientModules):
 
     def update_presence(self, include_muc: bool = True) -> None:
         status, message, idle = self.get_presence_state()
-        self._priority = app.get_priority(self._account, status)
         self.get_module('Presence').send_presence(
-            priority=self._priority,
             show=status,
             status=message,
             idle_time=idle)
@@ -484,7 +479,6 @@ class Client(Observable, ClientModules):
 
         self.get_module('Bookmarks').request_bookmarks()
         self.get_module('SoftwareVersion').set_enabled(True)
-        self.get_module('EntityTime').set_enabled(True)
         self.get_module('LastActivity').set_enabled(True)
         self.get_module('Annotations').request_annotations()
         self.get_module('Blocking').get_blocking_list()
