@@ -8,7 +8,7 @@ from typing import NamedTuple
 
 from dataclasses import dataclass
 from datetime import datetime
-from datetime import timezone
+from datetime import UTC
 from enum import Enum
 from enum import IntEnum
 from enum import unique
@@ -38,6 +38,7 @@ class EncryptionInfoMsg(Enum):
                       'Querying for devices now…')
     UNDECIDED_FINGERPRINTS = _('There are devices for which you have not made '
                                'a trust decision yet.')
+    SESSION_BUILD = _('Successfully build new session with {device_id}.')
 
 
 class Entity(NamedTuple):
@@ -55,10 +56,13 @@ class RowHeaderType(IntEnum):
 class AvatarSize(IntEnum):
     TAB = 16
     SHOW_CIRCLE = 24
+    SMALL = 24
     ROSTER = 32
+    START_CHAT = 32
     VCARD_HEADER = 40
-    ACCOUNT_SIDE_BAR = 40
-    WORKSPACE = 40
+    ACCOUNT_SIDE_BAR = 24
+    ACCOUNT_SIDE_BAR_WARNING = 20
+    WORKSPACE = 36
     WORKSPACE_EDIT = 100
     CHAT = 48
     MESSAGE_REPLY = 24
@@ -66,15 +70,16 @@ class AvatarSize(IntEnum):
     CALL = 100
     CALL_BIG = 200
     GROUP_INFO = 100
-    TOOLTIP = 100
+    TOOLTIP = 72
     ACCOUNT_PAGE = 150
+    ACTIVITY_PAGE = 100
     VCARD = 200
     PUBLISH = 200
 
 
 class ArchiveState:
     NEVER = None
-    ALL = datetime(1970, 1, 1, tzinfo=timezone.utc)
+    ALL = datetime(1970, 1, 1, tzinfo=UTC)
 
 
 @unique
@@ -82,6 +87,7 @@ class PathLocation(IntEnum):
     CONFIG = 0
     CACHE = 1
     DATA = 2
+    NONE = 3
 
 
 @unique
@@ -100,7 +106,7 @@ class StyleAttr(Enum):
 
 @unique
 class CSSPriority(IntEnum):
-    PRE_APPLICATION = 599
+    PRE_THEME = 199
     APPLICATION = 600
     APPLICATION_DARK = 601
     DEFAULT_THEME = 610
@@ -160,18 +166,6 @@ class Display(Enum):
     QUARTZ = 'GdkQuartzDisplay'
 
 
-class URIType(Enum):
-    INVALID = 'invalid'
-    XMPP = 'xmpp'
-    MAIL = 'mail'
-    GEO = 'geo'
-    WEB = 'web'
-    FILE = 'file'
-    AT = 'at'
-    TEL = 'tel'
-    OTHER = 'other'
-
-
 # https://xmpp.org/registrar/querytypes.html
 class XmppUriQuery(Enum):
     NONE = ''
@@ -196,6 +190,7 @@ class XmppUriQuery(Enum):
 class MUCJoinedState(Enum):
     JOINED = 'joined'
     NOT_JOINED = 'not joined'
+    BEFORE_JOINING = 'before joining'
     JOINING = 'joining'
     CREATING = 'creating'
     CAPTCHA_REQUEST = 'captcha in progress'
@@ -217,6 +212,10 @@ class MUCJoinedState(Enum):
     def is_joining(self):
         return self == MUCJoinedState.JOINING
 
+    @property
+    def is_before_joining(self):
+        return self == MUCJoinedState.BEFORE_JOINING
+
     @property
     def is_creating(self):
         return self == MUCJoinedState.CREATING
@@ -491,15 +490,16 @@ ARTISTS = [
 ]
 
 
-DEVS_CURRENT = [
-    'Yann Leboulanger (asterix AT lagaule.org)',
+MAINTAINERS = [
     'Philipp Hörist (philipp AT hoerist.com)',
     'Daniel Brötzmann (wurstsalat AT posteo.de)',
-    'André Apitzsch',
 ]
 
 
-DEVS_PAST = [
+DEVELOPERS = [
+    'Marc Henning',
+    'André Apitzsch',
+    'Yann Leboulanger (asterix AT lagaule.org)',
     'Stefan Bethge (stefan AT lanpartei.de)',
     'Alexander Cherniuk (ts33kr AT gmail.com)',
     'Stephan Erb (steve-e AT h3c.de)',
@@ -861,15 +861,17 @@ COMMON_FEATURES = [
     Namespace.HASHES_BLAKE2B_256,
     Namespace.HASHES_BLAKE2B_512,
     Namespace.JINGLE,
-    Namespace.JINGLE_FILE_TRANSFER_5,
-    Namespace.JINGLE_BYTESTREAM,
-    Namespace.JINGLE_IBB,
+    # TODO Jingle FT
+    # Namespace.JINGLE_FILE_TRANSFER_5,
+    # Namespace.JINGLE_BYTESTREAM,
+    # Namespace.JINGLE_IBB,
     Namespace.AVATAR_METADATA + '+notify',
     Namespace.MESSAGE_MODERATE,
     Namespace.REPLY,
     Namespace.OMEMO_TEMP_DL + '+notify',
     Namespace.STYLING,
     Namespace.REACTIONS,
+    Namespace.MDS + '+notify',
 ]
 
 
@@ -1032,16 +1034,16 @@ MIME_TYPES = (
 
 
 TRUST_SYMBOL_DATA = {
-    Trust.UNTRUSTED: ('dialog-error-symbolic',
+    Trust.UNTRUSTED: ('lucide-circle-x-symbolic',
                       _('Untrusted'),
                       'error-color'),
-    Trust.UNDECIDED: ('security-low-symbolic',
+    Trust.UNDECIDED: ('lucide-shield-alert-symbolic',
                       _('Trust Not Decided'),
                       'warning-color'),
-    Trust.BLIND: ('security-medium-symbolic',
-                  _('Unverified'),
+    Trust.BLIND: ('lucide-shield-question-mark-symbolic',
+                  _('Blind Trust'),
                   'encrypted-color'),
-    Trust.VERIFIED: ('security-high-symbolic',
+    Trust.VERIFIED: ('lucide-shield-check-symbolic',
                      _('Verified'),
                      'encrypted-color')
 }
@@ -1086,3 +1088,7 @@ TLS_VERSION_STRINGS = {
     4: '1.2',
     5: '1.3',
 }
+
+
+RETRACTION_FALLBACK = (
+    "/me retracted a previous message, but it's unsupported by your client.")
