@@ -122,12 +122,11 @@ class Roster(BaseModule):
         self._store_roster()
 
     def _process_roster_push(self,
-                             _con: types.xmppClient,
+                             _con: types.NBXMPPClient,
                              _stanza: Iq,
                              properties: IqProperties
                              ) -> None:
         self._log.info('Push received')
-
         assert properties.roster is not None
         item = properties.roster.item
         if item.subscription == 'remove':
@@ -146,6 +145,12 @@ class Roster(BaseModule):
         app.ged.raise_event(RosterPush(account=self._account,
                                        item=item))
 
+        contact = self._con.get_module('Contacts').get_contact(item.jid)
+        if contact is None:
+            return
+
+        contact.notify('nickname-update')
+
         raise nbxmpp.NodeProcessed
 
     def get_item(self, jid: JID) -> RosterItem | None:
@@ -193,9 +198,26 @@ class Roster(BaseModule):
         groups.add(new_group)
         self._nbxmpp('Roster').set_item(jid, item.name, groups)
 
+    def add_to_group(self, jid: JID, group: str) -> None:
+        item = self.get_item(jid)
+        assert item is not None
+        new_groups = item.groups | {group}
+        self._nbxmpp('Roster').set_item(jid, item.name, new_groups)
+
+    def remove_from_group(self, jid: JID, group: str) -> None:
+        item = self.get_item(jid)
+        assert item is not None
+        new_groups = item.groups - {group}
+        self._nbxmpp('Roster').set_item(jid, item.name, new_groups)
+
+    def change_name(self, jid: JID, name: str | None) -> None:
+        item = self.get_item(jid)
+        assert item is not None
+        self._nbxmpp('Roster').set_item(jid, name, item.groups)
+
     def iter(self) -> Iterator[tuple[JID, RosterItem]]:
         yield from self._roster.items()
 
     def iter_contacts(self) -> Iterator[BareContact]:
         for jid in self._roster:
-            yield self._get_contact(jid)
+            yield cast(BareContact, self._get_contact(jid))
