@@ -6,17 +6,17 @@ from __future__ import annotations
 
 import datetime as dt
 
-FIRST_UTC_DATETIME = dt.datetime(1970, 1, 1, tzinfo=dt.timezone.utc)
+FIRST_UTC_DATETIME = dt.datetime(1970, 1, 1, tzinfo=dt.UTC)
 FIRST_LOCAL_DATETIME = FIRST_UTC_DATETIME.astimezone()
 
 
 def convert_epoch_to_local_datetime(utc_timestamp: float) -> dt.datetime:
-    utc = dt.datetime.fromtimestamp(utc_timestamp, tz=dt.timezone.utc)
+    utc = dt.datetime.fromtimestamp(utc_timestamp, tz=dt.UTC)
     return utc.astimezone()
 
 
 def utc_now() -> dt.datetime:
-    return dt.datetime.now(dt.timezone.utc)
+    return dt.datetime.now(dt.UTC)
 
 
 def get_start_of_day(datetime: dt.datetime) -> dt.datetime:
