@@ -73,6 +73,7 @@ class ChatListRow(Gtk.ListBoxRow, SignalManager):
         self.workspace_id = workspace_id
         self.type = type_
         self.position = position
+        self._has_draft = False
 
         self._conversations_header = RowHeader(RowHeaderType.CONVERSATIONS)
         self._pinned_header = RowHeader(RowHeaderType.PINNED)
@@ -141,7 +142,9 @@ class ChatListRow(Gtk.ListBoxRow, SignalManager):
         if isinstance(self.contact, GroupchatContact) and not self.contact.can_notify():
             self._ui.unread_label.add_css_class("unread-counter-silent")
 
-        self._display_last_conversation_row()
+        draft = app.storage.drafts.get(self.contact)
+        if not self._set_draft_mode(draft):
+            self._display_last_conversation_row()
 
     def _display_last_conversation_row(self) -> None:
         message = app.storage.archive.get_last_conversation_row(
@@ -194,17 +197,21 @@ class ChatListRow(Gtk.ListBoxRow, SignalManager):
             self.message_id = message.id
 
         if message.filetransfers:
-            self.set_message_text(_("File"), icon_name="text-x-generic-symbolic")
+            self.set_message_text(_("File"), icon_name="lucide-paperclip-symbolic")
             self.set_timestamp(message.timestamp)
 
         if message.call is not None:
-            self.set_message_text(_("Call"), icon_name="call-start-symbolic")
+            self.set_message_text(_("Call"), icon_name="lucide-phone-symbolic")
             self.set_timestamp(message.timestamp)
 
     @property
     def is_pinned(self) -> bool:
         return self._pinned
 
+    @property
+    def has_draft(self) -> bool:
+        return self._has_draft
+
     @property
     def unread_count(self) -> int:
         if (
@@ -259,17 +266,13 @@ class ChatListRow(Gtk.ListBoxRow, SignalManager):
         oob: list[mod.OOB] | None = None,
     ) -> None:
 
+        if self._has_draft:
+            return
+
         assert isinstance(
             self.contact, BareContact | GroupchatContact | GroupchatParticipant
         )
 
-        draft = app.storage.drafts.get(self.contact)
-        if draft is not None:
-            self._show_draft(draft)
-            return
-
-        self._ui.message_label.remove_css_class("draft")
-
         icon = None
         if icon_name is not None:
             icon = Gio.Icon.new_for_string(icon_name)
@@ -278,7 +281,7 @@ class ChatListRow(Gtk.ListBoxRow, SignalManager):
             scheme = urlparse(text).scheme
             if scheme == "geo":
                 location = split_geo_uri(text)
-                icon = Gio.Icon.new_for_string("mark-location")
+                icon = Gio.Icon.new_for_string("lucide-map-pin-symbolic")
                 text = format_geo_coords(float(location.lat), float(location.lon))
             else:
                 file_name = filename_from_uri(text)
@@ -421,17 +424,22 @@ class ChatListRow(Gtk.ListBoxRow, SignalManager):
         if contact != self.contact:
             return
 
-        self._show_draft(draft)
+        if not self._set_draft_mode(draft):
+            self._display_last_conversation_row()
+        self.changed()
+
+    def _set_draft_mode(self, draft: Draft | None) -> bool:
+        self._has_draft = draft is not None
 
-    def _show_draft(self, draft: Draft | None) -> None:
         if draft is None:
             self._ui.message_label.remove_css_class("draft")
-            self._display_last_conversation_row()
-            return
 
-        self.set_nick("")
-        self._ui.message_label.set_text(_("Draft: %s") % draft.text)
-        self._ui.message_label.add_css_class("draft")
+        else:
+            self.set_nick("")
+            self._ui.message_label.set_text(_("Draft: %s") % draft.text)
+            self._ui.message_label.add_css_class("draft")
+
+        return self._has_draft
 
     def _on_state_flags_changed(
         self, _row: ChatListRow, _flags: Gtk.StateFlags
@@ -458,6 +466,7 @@ class ChatListRow(Gtk.ListBoxRow, SignalManager):
         app.check_finalize(self)
 
     def _on_close_button_clicked(self, _button: Gtk.Button) -> None:
+        self.reset_unread()
         app.window.activate_action(
             "win.remove-chat", GLib.Variant("as", [self.account, str(self.jid)])
         )
@@ -571,13 +580,13 @@ class ChatListRow(Gtk.ListBoxRow, SignalManager):
 
         assert isinstance(self.contact, GroupchatContact)
         if self.contact.is_joining:
-            self._ui.connection_icon.set_from_icon_name("feather-refresh-cw-symbolic")
+            self._ui.connection_icon.set_from_icon_name("lucide-refresh-cw-symbolic")
             self._ui.connection_icon.add_css_class("spin")
             self._ui.connection_icon.add_css_class("dimmed")
             self._ui.connection_icon.set_tooltip_text(_("Joining Group Chat…"))
             self._ui.connection_icon.set_visible(True)
         elif self.contact.is_not_joined or not self._client.state.is_available:
-            self._ui.connection_icon.set_from_icon_name("feather-zap-symbolic")
+            self._ui.connection_icon.set_from_icon_name("lucide-zap-symbolic")
             self._ui.connection_icon.add_css_class("warning")
             self._ui.connection_icon.set_tooltip_text(_("Not connected"))
             self._ui.connection_icon.set_visible(True)
@@ -589,7 +598,7 @@ class ChatListRow(Gtk.ListBoxRow, SignalManager):
         self._reset_connection_icon()
 
         if signal_name == "mam-sync-started":
-            self._ui.connection_icon.set_from_icon_name("feather-refresh-cw-symbolic")
+            self._ui.connection_icon.set_from_icon_name("lucide-refresh-cw-symbolic")
             self._ui.connection_icon.add_css_class("spin")
             self._ui.connection_icon.add_css_class("accent")
             self._ui.connection_icon.set_tooltip_text(_("Fetching messages…"))
@@ -600,7 +609,7 @@ class ChatListRow(Gtk.ListBoxRow, SignalManager):
     ) -> None:
 
         self._reset_connection_icon()
-        self._ui.connection_icon.set_from_icon_name("feather-zap-symbolic")
+        self._ui.connection_icon.set_from_icon_name("lucide-zap-symbolic")
         self._ui.connection_icon.add_css_class("error")
         self._ui.connection_icon.set_tooltip_text(
             _("There has been an error while trying to fetch messages: %s") % error_text
