@@ -38,12 +38,12 @@ from gajim.common.const import PresenceShowExt
 from gajim.common.const import RFC5646_LANGUAGE_TAGS
 from gajim.common.helpers import to_user_string
 from gajim.common.i18n import _
-from gajim.common.i18n import get_rfc5646_lang
 from gajim.common.modules.contacts import BareContact
 from gajim.common.modules.contacts import GroupchatContact
 from gajim.common.modules.util import as_task
 from gajim.common.util.jid import validate_jid
 from gajim.common.util.muc import get_group_chat_nick
+from gajim.common.util.standards import get_rfc5646_lang
 from gajim.common.util.status import compare_show
 from gajim.common.util.text import to_one_line
 from gajim.common.util.uri import parse_uri
@@ -60,8 +60,6 @@ from gajim.gtk.menus import get_start_chat_row_menu
 from gajim.gtk.util.classes import SignalManager
 from gajim.gtk.util.icons import get_icon_theme
 from gajim.gtk.util.misc import get_ui_string
-
-# from gajim.gtk.tooltips import ContactTooltip
 from gajim.gtk.widgets import AccountBadge
 from gajim.gtk.widgets import GajimAppWindow
 from gajim.gtk.widgets import GajimPopover
@@ -77,6 +75,9 @@ log = logging.getLogger("gajim.gtk.start_chat")
 
 
 class StartChatDialog(GajimAppWindow):
+
+    last_chat_filters = ChatFilters()
+
     def __init__(
         self, initial_jid: str | None = None, initial_message: str | None = None
     ) -> None:
@@ -147,7 +148,7 @@ class StartChatDialog(GajimAppWindow):
         self._connect(
             self._ui.search_entry,
             "stop-search",
-            lambda *args: self._ui.search_entry.set_text(""),
+            lambda *args: self._ui.search_entry.set_text(""),  # type: ignore
         )
         self._connect(
             self._ui.stack, "notify::visible-child-name", self._on_page_changed
@@ -203,7 +204,11 @@ class StartChatDialog(GajimAppWindow):
         self._connect(action, "change-state", self._on_sort_by_show_changed)
         self.window.add_action(action)
 
+        self._ui.search_entry.grab_focus()
         log.debug("Loading dialog finished")
+
+        self._chat_filter.set_filters(StartChatDialog.last_chat_filters)
+
         self.show()
 
     def _cleanup(self, *args: Any) -> None:
@@ -216,7 +221,7 @@ class StartChatDialog(GajimAppWindow):
         self._destroyed = True
         app.cancel_tasks(self)
 
-    def remove_row(self, account: str, jid: str) -> None:
+    def remove_row(self, account: str, jid: JID) -> None:
         # Used by forget-groupchat action
         self._contact_view.remove(account, jid)
 
@@ -244,6 +249,8 @@ class StartChatDialog(GajimAppWindow):
                     # Workaround if groupchats are in the roster
                     continue
 
+                assert isinstance(contact, BareContact)
+
                 item = ContactListItem(
                     account,
                     contact,
@@ -258,6 +265,7 @@ class StartChatDialog(GajimAppWindow):
             self_contact = client.get_module("Contacts").get_contact(
                 client.get_own_jid().bare
             )
+            assert isinstance(self_contact, BareContact)
             item = ContactListItem(
                 account,
                 self_contact,
@@ -282,6 +290,7 @@ class StartChatDialog(GajimAppWindow):
                 contact = client.get_module("Contacts").get_contact(
                     bookmark.jid, groupchat=True
                 )
+                assert isinstance(contact, GroupchatContact)
 
                 item = ContactListItem(
                     account,
@@ -475,6 +484,8 @@ class StartChatDialog(GajimAppWindow):
         app.settings.set("show_help_start_chat", False)
 
     def _on_chat_filter_changed(self, chat_filter: ChatFilter) -> None:
+        filters = chat_filter.get_filters()
+        StartChatDialog.last_chat_filters = filters
         self._contact_view.set_chat_filter(chat_filter.get_filters())
 
     def _prepare_new_chat(self, item: ContactListItem) -> None:
@@ -946,8 +957,8 @@ class ContactListView(BaseListView[type["ContactListItem"], type["ContactViewIte
 
     @staticmethod
     def _sort_func(
-        obj1: Any,
-        obj2: Any,
+        obj1: ContactListItem,
+        obj2: ContactListItem,
         _user_data: object | None,
     ) -> int:
 
@@ -971,7 +982,7 @@ class ContactListView(BaseListView[type["ContactListItem"], type["ContactViewIte
         self._model.append(item)
 
     def remove(self, account: str, jid: JID) -> None:
-        for item in self._model:
+        for item in cast(list[ContactListItem], self._model):
             if item.account != account or item.jid != jid:
                 continue
             success, pos = self._model.find(item)
@@ -1020,7 +1031,7 @@ class ContactListItem(GObject.Object):
         groupchat: bool = False,
     ) -> None:
 
-        name = name or _("Start New Chat")
+        name = name or _("Start / Join Chat")
 
         idle = None
         status = ""
@@ -1028,6 +1039,7 @@ class ContactListItem(GObject.Object):
         show = PresenceShowExt.OFFLINE
         is_self = False
         if contact is not None and not groupchat:
+            assert isinstance(contact, BareContact)
             groups = sorted(contact.groups)
             status = to_one_line(contact.status)
             idle = contact.idle_datetime
@@ -1042,15 +1054,16 @@ class ContactListItem(GObject.Object):
         if is_new:
             theme = get_icon_theme()
             avatar_paintable = theme.lookup_icon(
-                "feather-user-plus-symbolic",
+                "lucide-user-plus-symbolic",
                 None,
                 AvatarSize.START_CHAT,
                 scale,
                 Gtk.TextDirection.NONE,
-                0,
+                0,  # type: ignore
             )
 
         else:
+            assert isinstance(contact, BareContact | GroupchatContact)
             avatar_paintable = contact.get_avatar(AvatarSize.START_CHAT, scale)
 
         search_string = "|".join((name, str(jid))).lower()
@@ -1081,7 +1094,7 @@ class ContactListItem(GObject.Object):
 class ContactViewItem(Gtk.Grid, SignalManager):
     __gtype_name__ = "ContactViewItem"
 
-    _avatar: Gtk.Label = Gtk.Template.Child()
+    _avatar: Gtk.Image = Gtk.Template.Child()
     _name_label: Gtk.Label = Gtk.Template.Child()
     _address_label: Gtk.Label = Gtk.Template.Child()
     _status_label: Gtk.Label = Gtk.Template.Child()
@@ -1096,18 +1109,13 @@ class ContactViewItem(Gtk.Grid, SignalManager):
 
         self.__bindings: list[GObject.Binding] = []
 
-        # TODO: add back tooltip
-        # self._tooltip = ContactTooltip()
-        # image.set_has_tooltip(True)
-        # self._connect(image, 'query-tooltip', self._on_query_tooltip)
-
         gesture_secondary_click = Gtk.GestureClick(
             button=Gdk.BUTTON_SECONDARY, propagation_phase=Gtk.PropagationPhase.BUBBLE
         )
         self._connect(gesture_secondary_click, "pressed", self._popup_menu)
         self.add_controller(gesture_secondary_click)
 
-    def bind(self, obj: GlobalListItem) -> None:
+    def bind(self, obj: ContactListItem) -> None:
         bind_spec = [
             ("name", self._name_label, "label"),
             ("jid", self._address_label, "label"),
@@ -1127,6 +1135,9 @@ class ContactViewItem(Gtk.Grid, SignalManager):
             )
             self.__bindings.append(bind)
 
+        if obj.is_new:
+            self._avatar.add_css_class("dimmed")
+
     def unbind(self) -> None:
         for bind in self.__bindings:
             bind.unbind()
@@ -1137,18 +1148,6 @@ class ContactViewItem(Gtk.Grid, SignalManager):
         Gtk.Grid.do_unroot(self)
         app.check_finalize(self)
 
-    # def _on_query_tooltip(self,
-    #                       _img: Gtk.Image,
-    #                       _x_coord: int,
-    #                       _y_coord: int,
-    #                       _keyboard_mode: bool,
-    #                       tooltip: Gtk.Tooltip) -> bool:
-    #     if not isinstance(self.contact, BareContact):
-    #         return False
-    #     v, widget = self._tooltip.get_tooltip(self.contact)
-    #     tooltip.set_custom(widget)
-    #     return v
-
     def _popup_menu(
         self,
         _gesture_click: Gtk.GestureClick,
